@@ -1,7 +1,7 @@
 /*
  * libbrlapi - A library providing access to braille terminals for applications.
  *
- * Copyright (C) 2002-2018 by
+ * Copyright (C) 2002-2019 by
  *   Samuel Thibault <Samuel.Thibault@ens-lyon.org>
  *   Sébastien Hinderer <Sebastien.Hinderer@ens-lyon.org>
  *
@@ -12,7 +12,7 @@
  * Foundation; either version 2.1 of the License, or (at your option) any
  * later version. Please see the file LICENSE-LGPL for details.
  *
- * Web Page: http://brltty.com/
+ * Web Page: http://brltty.app/
  *
  * This software is maintained by Dave Mielke <dave@mielke.cc>.
  */
@@ -280,6 +280,10 @@ extern "C" {
 #define BRLAPI_KEY_CMD_NXNBWIN (BRLAPI_KEY_CMD(0) + 123)
 /** set touch navigation on/off */
 #define BRLAPI_KEY_CMD_TOUCH_NAV (BRLAPI_KEY_CMD(0) + 124)
+/** speak indent of current line */
+#define BRLAPI_KEY_CMD_SPEAK_INDENT (BRLAPI_KEY_CMD(0) + 125)
+/** set autospeak indent of current line on/off */
+#define BRLAPI_KEY_CMD_ASPK_INDENT (BRLAPI_KEY_CMD(0) + 126)
 /** bring screen cursor to character */
 #define BRLAPI_KEY_CMD_ROUTE BRLAPI_KEY_CMD(1)
 /** start new clipboard at character */
@@ -298,7 +302,7 @@ extern "C" {
 #define BRLAPI_KEY_CMD_COPY_LINE BRLAPI_KEY_CMD(5)
 /** deprecated definition of COPY_LINE - linear copy to character */
 #define BRLAPI_KEY_CMD_CUTLINE BRLAPI_KEY_CMD(5)
-/** switch to a specific virtual terminal */
+/** switch to specific virtual terminal */
 #define BRLAPI_KEY_CMD_SWITCHVT BRLAPI_KEY_CMD(6)
 /** go up to nearest line with less indent than character */
 #define BRLAPI_KEY_CMD_PRINDENT BRLAPI_KEY_CMD(7)
@@ -338,7 +342,7 @@ extern "C" {
 #define BRLAPI_KEY_CMD_SET_KEYBOARD_TABLE BRLAPI_KEY_CMD(22)
 /** set language profile */
 #define BRLAPI_KEY_CMD_SET_LANGUAGE_PROFILE BRLAPI_KEY_CMD(23)
-/** bind to a specific virtual terminal */
+/** bind to specific virtual terminal */
 #define BRLAPI_KEY_CMD_SELECTVT BRLAPI_KEY_CMD(30)
 /** render an alert */
 #define BRLAPI_KEY_CMD_ALERT BRLAPI_KEY_CMD(31)
